geom_line_saber: Lightsaber themed line plots

Description Usage Arguments Details Value Examples

Description

Glowing Lines, lightly colored area plots for a cyberpunk/Laser sword themed line plot

Usage

1
2
3
4
5
6
7
8
geom_linesaber(
  alpha = 1,
  size = 1.25,
  glow_alpha = 0.05,
  layers = 10,
  glow_size = 0.65,
  inner_color = "white"
)

Arguments

alpha

set the alpha level for the base line.

size

set the base line size.

glow_alpha

alpha level for the glow effect

layers

number of glowing layers to draw,

glow_size

size of the glow

inner_color

color of the inner line

Details

Create a cyberpunk themed chart using ggplot. This plot is a fancy line plot, that uses a glow effect around the line.

Value

A list of ggplot geoms containing, geom_lines, and geom_point. geom_linesaber does not return a geom_point

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
## Not run: 
library(ggplot2)
library(tidyverse)

df = data.frame(A=c(1,4,4,6,7,5,1),
               B=c(4,3,5,7,5,6,7),
               I=c(1,2,3,4,5,6,7)) %>%
pivot_longer(cols = c(A,B),names_to = "group", values_to = "count")


df %>%
   ggplot(aes(x=I, y = count, color = group, fill= group))+
     geom_linesaber()+
     theme_cyberpunk()+
     scale_fill_manual(values = c("#08F7FE", "#FE53BB"))+
     scale_color_manual(values = c("#08F7FE", "#FE53BB"))

## End(Not run)

delabj/ggCyberPunk documentation built on Nov. 17, 2021, 7:40 p.m.