Description Usage Arguments Details
A theme to make beautiful cyer punk themed plots. Based of the theme newRetro in the vapoRwave package
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 | theme_cyberpunk(
font = "Aldrich",
main.text.color = "#EE9537",
sub.text.color = "#EE9537",
base.size = 15,
plot.background.color = "#212946",
legend.position = "bottom",
panel.border.color = "#494F67",
panel.background = "#212946",
panel.grid.color = "#EE9537",
axis.text.color = "#EE9537",
axis.text.size = base.size * 0.6666667,
subtitle.size = base.size * 0.8,
legend.text = base.size * 0.8,
legend.title = base.size * 0.85,
axis.title.size = base.size * 0.8,
title.size = 15
)
|
font |
sets the default font |
main.text.color |
sets the main text color |
sub.text.color |
sets the subtext color |
base.size |
sets the base font size |
plot.background.color |
sets the background color |
legend.position |
sets the default legend position |
panel.border.color |
sets the panel border color |
panel.background |
sets the background color for the plot |
panel.grid.color |
sets the grid color for the plot |
axis.text.color |
sets the axis text color |
axis.text.size |
sets the axis text size |
subtitle.size |
sets the subtitle size |
legend.text |
sets the title text size |
legend.title |
sets the legend title size |
axis.title.size |
sets the axis title size, |
title.size |
sets the title size |
A theme designed to work with the glowing lines plots to provide a cyber punk feel.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.